Tutorial
========

.. admonition:: Estimated time

    * 3 hours

Grab your laptop and coffee, and dive into this 7-module tutorial to become a Merlin expert.

This hands-on tutorial introduces Merlin
through some example workflows. In it, you will install Merlin on your local
machine, stand up a virtual server and run both a simple workflow and a
quasi-real-life physicsy simulation that couples a physics application with
visualization and machine learning.

You'll also learn how to use some advanced features and help make Merlin better.
Finally we offer some tips and tricks for porting and scaling up your application.

..    :doc:`0. Prerequisites<prereqs>`

.. toctree::
   :maxdepth: 1
   :caption: Before you come:

   modules/before

.. toctree::
   :maxdepth: 1
   :numbered:
   :caption: Tutorial modules:

   modules/introduction
   modules/installation/installation
   modules/hello_world/hello_world
   modules/run_simulation/run_simulation
   modules/advanced_topics/advanced_topics
   modules/contribute
   modules/port_your_application
